# OME/Web/DBObjRender/__Pixels.pm
#-------------------------------------------------------------------------------
#
# Copyright (C) 2003 Open Microscopy Environment
#		Massachusetts Institute of Technology,
#		National Institutes of Health,
#		University of Dundee
#
#
#
#	 This library is free software; you can redistribute it and/or
#	 modify it under the terms of the GNU Lesser General Public
#	 License as published by the Free Software Foundation; either
#	 version 2.1 of the License, or (at your option) any later version.
#
#	 This library is distributed in the hope that it will be useful,
#	 but WITHOUT ANY WARRANTY; without even the implied warranty of
#	 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#	 Lesser General Public License for more details.
#
#	 You should have received a copy of the GNU Lesser General Public
#	 License along with this library; if not, write to the Free Software
#	 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#-------------------------------------------------------------------------------




#-------------------------------------------------------------------------------
#
# Written by:  
#	Josiah Johnston <siah@nih.gov>
#
#-------------------------------------------------------------------------------


package OME::Web::DBObjRender::__Pixels;

=pod

=head1 NAME

OME::Web::DBObjRender::__Pixels - specialized rendering of Pixels ST

=head1 DESCRIPTION

Provides custom behavior for rendering Pixels ST

=head1 METHODS

=cut

use strict;
use OME;
our $VERSION = $OME::VERSION;
use OME::Tasks::PixelsManager;
use base qw(OME::Web::DBObjRender);
use Carp qw(cluck);

sub new {
	my $proto = shift;
	my $class = ref($proto) || $proto;
	my $self  = $class->SUPER::new(@_);
	
	$self->{ _summaryFields } = [
		'id',
		'SizeX',
		'SizeY',
		'SizeZ',
		'SizeC',
		'SizeT',
		'image',
		'module_execution'
	];
	$self->{ _allFields } = [
		@{ $self->{ _summaryFields } },
		'PixelType',
		'FileSHA1',
		'ImageServerID',
		'Repository'
	];
	
	return $self;
}


=head2 _getRef

html format returns a thumbnail linking to the image viewer and a link
to the Pixels attribute.

=cut

sub _getRef {
	my ($self,$obj,$format) = @_;

	for( $format ) {
		if( /^txt$/ ) {
			return $obj->id();
		}
		if( /^html$/ ) {
			my ($package_name, $common_name, $formal_name, $ST) =
				$self->_loadTypeAndGetInfo( $obj );
			my $id   = $obj->id();
			my $source_module; $source_module = $obj->module_execution()->module()->name()
				if $obj->module_execution() and $obj->module_execution()->module();
			my $thumbURL = OME::Tasks::PixelsManager->getThumbURL($id); 
			my $ref = "<a href='serve.pl?Page=OME::Web::DBObjDetail&Type=$formal_name&ID=$id' title='Detailed Information about this Pixels attribute' class='ome_detail'>Pixels info</a><br>".
			          "<a href='javascript: openPopUpPixels($id);' title='View this pixel set'><img src='$thumbURL'></a>";
			return $ref;
		}
	}
}

=head2 getRefSearchField

No search field to Pixels

=cut

sub _getRefSearchField {
	my ($self, $from_type, $to_type, $accessor_to_type, $default) = @_;
	
	return ();
}



=head1 Author

Josiah Johnston <siah@nih.gov>

=cut

1;
